@@ -1,16 +1,17 @@
 from __future__ import annotations
 
+from typing import ClassVar
+
 from cleo.commands.command import Command
 from cleo.io.inputs.argument import Argument
 
 
 class HelpCommand(Command):
-
     name = "help"
 
     description = "Displays help for a command."
 
-    arguments = [
+    arguments: ClassVar[list[Argument]] = [
         Argument(
             "command_name",
             required=False,
