@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
+from typing import ClassVar
 
 from cleo.commands.command import Command
 
@@ -10,12 +11,11 @@ if TYPE_CHECKING:
 
 
 class FooCommand(Command):
-
     name = "foo bar"
 
     description = "The foo bar command"
 
-    aliases = ["afoobar"]
+    aliases: ClassVar[list[str]] = ["afoobar"]
 
     def interact(self, io: IO) -> None:
         io.write_line("interact called")
