@@ -1,15 +1,16 @@
 from __future__ import annotations
 
+from typing import ClassVar
+
 from cleo.commands.command import Command
 
 
 class FooSubNamespaced3Command(Command):
-
     name = "foo bar"
 
     description = "The foo bar command"
 
-    aliases = ["foobar"]
+    aliases: ClassVar[list[str]] = ["foobar"]
 
     def handle(self) -> int:
         question = self.ask("", default="default input")
