@@ -29,13 +29,11 @@ def test_format_time(input_secs: float, expected: str) -> None:
 @pytest.mark.parametrize(
     ["name", "expected"],
     [
-        ("", ["help", "foo1", "foo2", "bar1", "bar2", "foo bar1", "foo bar2"]),
-        ("hellp", ["help"]),
-        ("bar2", ["bar2", "bar1", "foo bar2"]),
-        ("bar1", ["bar1", "bar2", "foo bar1"]),
-        ("foo", ["foo1", "foo2", "foo bar1", "foo bar2"]),
+        ("env add", ["env remove", "env activate", "env info", "env list", "env use"]),
+        ("evn add", ["env activate", "env use"]),
+        ("env", ["env remove", "env info", "env list", "env use"]),
     ],
 )
 def test_find_similar_names(name: str, expected: list[str]) -> None:
-    names = ["help", "foo1", "foo2", "bar1", "bar2", "foo bar1", "foo bar2"]
+    names = ["env info", "env use", "env activate", "env remove", "env list"]
     assert find_similar_names(name, names) == expected
